Faber Tutorial
==============

.. tutorial outline
   
   * Introduction
     - how to invoke faber
     - what is a fabscript
   * Basic concepts
     - artefacts
     - actions
     - rules
     - features
   * Advanced concepts
     - tools
     - implicit rules and composite artefacts
     - project structure and modular builds
     - computed features and data flow
   * Special topics
     - configuration
     - testing

.. toctree::
   :maxdepth: 2

   basic_concepts
   advanced_concepts
   special_topics
